#
# spec file for package python-cdflib
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-cdflib
Version:        1.3.2
Release:        1.0.2.1.sr20241103
Summary:        A python CDF reader toolkit
License:        MIT
URL:            https://github.com/MAVENSDC/cdflib
# Tests only included in github archive
Source:         https://github.com/MAVENSDC/cdflib/archive/refs/tags/%{version}.tar.gz#/cdflib-%{version}-gh.tar.gz
# Test datafile, Public domain, not packaged
Source1:        https://helios-data.ssl.berkeley.edu/data/E1_experiment/New_proton_corefit_data_2017/cdf/helios1/1974/h1_1974_346_corefit.cdf
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 45}
BuildRequires:  %{python_module setuptools_scm >= 6.2}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-numpy >= 1.21
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module numpy >= 1.21}
BuildRequires:  %{python_module astropy}
BuildRequires:  %{python_module h5netcdf}
BuildRequires:  %{python_module hypothesis}
BuildRequires:  %{python_module netCDF4}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module xarray}
# /SECTION
%python_subpackages

%description
A python module to read/write CDF (Common Data Format .cdf) files without needing to install the CDF NASA library.

%prep
%setup -q -n cdflib-%{version}
sed -i '/addopts/ d' setup.cfg
# don't install benchmarks and tests gh#MAVENSDC/cdflib#274
sed -i 's/packages = find:$/packages = cdflib/' setup.cfg
cp %{SOURCE1} helios.cdf

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest -m "not remote_data"

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/cdflib
%{python_sitelib}/cdflib-%{version}.dist-info

%changelog
* Tue Nov 19 2024 Dirk Müller <dmueller@suse.com>
- update to 1.3.2:
  * Adding anonymous s3 access to cdflib
* Sat Aug 17 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.3.1
  * Added tox to serve as the unit testing infrastructure, and
    changed which unit tests were run (see the github actions to
    see what exactly is running)
  * Added tests to check future versions of numpy and astropy
  * Added back in the remote data unit tests
  * xarray_to_cdf: Added an ISTP check to determine is attribute
    and variable names are compliant
  * cdfwrite: Clearer error message surrounding data type
    conversions to CDF data types
- Version 1.0
  * Version 1.0.0 is a new major version for cdflib, and contains a
    number of breaking changes. These have been made to improve
    consistency across the package, and make it easier to maintain
    and build on the package going forward in the future.
  * Although we have tried our best to not introduce new bugs and
    list all changes below, some things may have slipped through
    the cracks. If you have any issues, please do not hesitate to
    open them at https://github.com/MAVENSDC/cdflib/issues.
  [#]# Python support
  * cdflib is now only tested on Python 3.8, 3.9, 3.10, and 3.11.
    It may work for older versions of Python, but this is not
    guarenteed. If you need to use cdflib on an older version of
    Python, please open an issue to discuss whether the cdflib
    maintainers can support this.
  [#]## Returning arrays
  * All to_np keyword arguments have been removed throughout the
    library, and the code now behaves as if to_np=True throughout.
    This change has been made to reduce code omplexity and make
    maintaining the code easier. If you need outputs as lists, call
    .tolist() on the output array.
  * to_np=True was the deafult in cdfread, so if you weren't
    specifying it behaviour will not change there. to_np=False was
    the default in epochs, so if you weren't specifying it there
    beahviour will change.
  * Changes to CDF method returns Most of the methods that return
    data from the CDF reader class have had their return types
    changed from dictionaries to dataclasses. This allows the
    return type to be more clearly documented (see
    :ref:dataclasses), for internal checks to be made to make sure
    data types are consistent, and a nicer representation when the
    return values are printed.
  * Where previously an item would have been accessed as
    dict["value"], items in the dataclasses can be accessed using
    dataclass.value.
  * The methods that have been updated are:
  - cdflib.cdfread.CDF.vdr_info
  - cdflib.cdfread.CDF.attinq
  - cdflib.cdfread.CDF.attget
  - cdflib.cdfread.CDF.varget
  - cdflib.cdfread.CDF.varinq
  [#]# Other breaking changes
  * The CDF factory class (cdflib.CDF) has been removed, and
    cdflib.CDF is now the reader class. This change has been made
    to prevent potential confusion when the user makes a mistake in
    specifying the file to open, and cdflib would silently create a
    writer class instead. If you want to create a CDF writer class,
    explicitly import cdflib.cdfwrite.CDF instead.
  * cdflib.cdfread.CDF.varget no longer takes an inq argument.
    Instead use the new method cdflib.cdfread.CDF.vdr_info to get
    the VDR info. getVersion() methods have been removed throughout
    the package. Instead the CDF version can be read from class
    attributes.
  * Removed cdflib.cdfepochs.CDFepoch.getLeapSecondLastUpdated.
  * Directly inspect CDFepoch.LTS instead to get the last date at
    which a leapsecond was added.
  * The expand keyword argument to cdflib.cdfread.CDF.varget has
    been removed.
  * Use CDF.varinq to get variable information instead.
  * The expand keyword argument to CDF.globalattsget and
    CDF.varattsget has been removed.
  * Use cdflib.cdfread.CDF.attinq to get attribute information
    instead.
  * Removed CDF.print_attrs
  * The version, release, and increement attributes of CDF have
    been removed.
  * Removed the record_range_only argument to
    cdflib.cdfread.CDF.varget.
  * Removed CDF.epochrange. Use cdflib.cdfread.CDF.varinq instead
    to get the data ranges.
* Sun Feb  6 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for version 0.3.20
- Required for sunpy testing
